Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(302)

Unified Diff: net/http/http_transaction_factory.h

Issue 222009: Replace some net::ERR_FAILED generic error codes with more specific codes.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Address wtc's comments Created 11 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/http/http_network_layer_unittest.cc ('k') | net/http/http_transaction_unittest.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/http_transaction_factory.h
===================================================================
--- net/http/http_transaction_factory.h (revision 26789)
+++ net/http/http_transaction_factory.h (working copy)
@@ -5,6 +5,8 @@
#ifndef NET_HTTP_HTTP_TRANSACTION_FACTORY_H__
#define NET_HTTP_HTTP_TRANSACTION_FACTORY_H__
+#include "base/scoped_ptr.h"
+
namespace net {
class HttpCache;
@@ -15,8 +17,9 @@
public:
virtual ~HttpTransactionFactory() {}
- // Creates a HttpTransaction object.
- virtual HttpTransaction* CreateTransaction() = 0;
+ // Creates a HttpTransaction object. On success, saves the new
+ // transaction to |*trans| and returns OK.
+ virtual int CreateTransaction(scoped_ptr<HttpTransaction>* trans) = 0;
// Returns the associated cache if any (may be NULL).
virtual HttpCache* GetCache() = 0;
« no previous file with comments | « net/http/http_network_layer_unittest.cc ('k') | net/http/http_transaction_unittest.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698